==> client-sso-oidc-3.36.1.tgz: package/dist-es/SSOOIDC.js <==
import { __extends } from "tslib";
import { CreateTokenCommand } from "./commands/CreateTokenCommand";
import { RegisterClientCommand, } from "./commands/RegisterClientCommand";
import { StartDeviceAuthorizationCommand, } from "./commands/StartDeviceAuthorizationCommand";
import { SSOOIDCClient } from "./SSOOIDCClient";
var SSOOIDC = (function (_super) {
    __extends(SSOOIDC, _super);
    function SSOOIDC() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SSOOIDC.prototype.createToken = function (args, optionsOrCb, cb) {
        var command = new CreateTokenCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get " + typeof optionsOrCb);
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    SSOOIDC.prototype.registerClient = function (args, optionsOrCb, cb) {
        var command = new RegisterClientCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get " + typeof optionsOrCb);
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    SSOOIDC.prototype.startDeviceAuthorization = function (args, optionsOrCb, cb) {
        var command = new StartDeviceAuthorizationCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get " + typeof optionsOrCb);
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    return SSOOIDC;
}(SSOOIDCClient));
export { SSOOIDC };

==> client-sso-oidc-3.58.0.tgz: package/dist-es/SSOOIDC.js <==
import { __extends } from "tslib";
import { CreateTokenCommand } from "./commands/CreateTokenCommand";
import { RegisterClientCommand, } from "./commands/RegisterClientCommand";
import { StartDeviceAuthorizationCommand, } from "./commands/StartDeviceAuthorizationCommand";
import { SSOOIDCClient } from "./SSOOIDCClient";
var SSOOIDC = (function (_super) {
    __extends(SSOOIDC, _super);
    function SSOOIDC() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SSOOIDC.prototype.createToken = function (args, optionsOrCb, cb) {
        var command = new CreateTokenCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get ".concat(typeof optionsOrCb));
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    SSOOIDC.prototype.registerClient = function (args, optionsOrCb, cb) {
        var command = new RegisterClientCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get ".concat(typeof optionsOrCb));
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    SSOOIDC.prototype.startDeviceAuthorization = function (args, optionsOrCb, cb) {
        var command = new StartDeviceAuthorizationCommand(args);
        if (typeof optionsOrCb === "function") {
            this.send(command, optionsOrCb);
        }
        else if (typeof cb === "function") {
            if (typeof optionsOrCb !== "object")
                throw new Error("Expect http options but get ".concat(typeof optionsOrCb));
            this.send(command, optionsOrCb || {}, cb);
        }
        else {
            return this.send(command, optionsOrCb);
        }
    };
    return SSOOIDC;
}(SSOOIDCClient));
export { SSOOIDC };
